/* -*- Mode: C++ -*- */

/* COPYING
 * Liquid Rendering Library
 * (c) 2009 by Henrik Theiling
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/* Also implements Latin1, because both are trivial */

#include "internal.h"

void liq_render_set_text_n_latin1 (LiqRender *self, LiqChar8 const *s, size_t n)
{
    liq_render_alloc_info (self, n);
    {
        LiqCharInfo *c= self->m_info;
        while (n--)
            liq_set_info (c++, (unsigned char)*s++);
    }
    liq_render_finalise_text (self);
}

void liq_render_set_text_n_utf32 (LiqRender *self, LiqChar32 const *s, size_t n)
{
    liq_render_alloc_info (self, n);
    {
        LiqCharInfo *c= self->m_info;
        while (n--)
            liq_set_info (c++, *s++);
    }
    liq_render_finalise_text (self);
}

static size_t my_strlen32 (LiqChar32 const *s)
{
    size_t n= 0;
    while (*s++) n++;
    return n;
}

void liq_render_set_text_latin1 (LiqRender *self, LiqChar8 const *text)
{
    liq_render_set_text_n_latin1 (self, text, strlen (text));
}

void liq_render_set_text_utf32 (LiqRender *self, LiqChar32 const *text)
{
    liq_render_set_text_n_utf32 (self, text, my_strlen32 (text));
}
